function [] = plot()
%PLOT Plots or updates the time of arrival points.
%   If the plot already exists and is valid, the points only get updated.
%   Otherwise the plot will be initialized
%

global artoaGui artoaWorkspace artoaDataInput;

%% Get all required values
% create color vector
correlationHeights = artoaWorkspace.toaData.correlationHeight./artoaWorkspace.float.correlationrange(2);

%c = repmat([.5 .5 .5], length(artoaWorkspace.toaData.toaDate), 1);
c = correlationHeights * 0.4;

soundsources = fieldnames(artoaDataInput.soundsources);
for i = 1:length(soundsources)
    selection = logical(artoaWorkspace.toaData.status == 1) ...
        & logical(strcmp(artoaWorkspace.toaData.soundSource, soundsources{i}));
    c(selection) = artoaWorkspace.soundSourceColorId(i) * 0.4 + 0.6;
end
%c(artoaWorkspace.toaData.status == 1) = correlationHeights(artoaWorkspace.toaData.status == 1) * 0.4 + 0.1;



if artoaWorkspace.showAllDataPoints
    x = artoaWorkspace.toaData.toaDate;
    y = artoaWorkspace.toaData.toa;
else
    % get all toa that are considered valid by temperature and pressure
    % selection
    temperature = repmat(artoaWorkspace.statusTemperature, length(artoaDataInput.rfb.VARIABLE_LIST.time_of_arrival), 1);
    pressure = repmat(artoaWorkspace.statusPressure, length(artoaDataInput.rfb.VARIABLE_LIST.time_of_arrival), 1);
    selection = temperature == 1 & pressure == 1 & artoaWorkspace.toaData.status ~= 2;
    x = artoaWorkspace.toaData.toaDate(selection);
    y = artoaWorkspace.toaData.toa(selection);
    c = c(selection, :);
    clear temperature pressure selection;
end

%% If the plot exists, just update the values

if isfield(artoaGui.editTimeOfArrival, 'scatterTimeOfArrival') ...
        && isvalid(artoaGui.editTimeOfArrival.scatterTimeOfArrival)
    artoaGui.editTimeOfArrival.scatterTimeOfArrival.XData = x;
    artoaGui.editTimeOfArrival.scatterTimeOfArrival.YData = y;
    artoaGui.editTimeOfArrival.scatterTimeOfArrival.CData = c;
    return
end

%% Create a new plot if non existent

hold on;

% get all points that are not deleted
artoaGui.editTimeOfArrival.scatterTimeOfArrival = scatter( ...
    artoaGui.figures.editTimeOfArrival.CurrentAxes, ...
    x, ...
    y, ...
    [], ...
    c, ... %'.', 'MarkerSize', 10 ...
    'filled' ...
);


% set colormap
colormap(artoaGui.figures.editTimeOfArrival.CurrentAxes, artoa.vendor.cmocean('tarn'));
artoaGui.figures.editTimeOfArrival.CurrentAxes.CLim = [0, 1];

%% Setup GPS information plot

artoa.controller.edit.timeOfArrival.plotSoundsourceToaFromGps(soundsources);
hold on;

%% Setup gui

grid on;

% set background color
set(artoaGui.figures.editTimeOfArrival.CurrentAxes, 'Color', [.3 .3 .3], 'XColor', 'blue', 'YColor', 'blue');

% set plot title
titleVal = [ ...
    'Project: ' artoaWorkspace.float.projectname ...
    ' FloatId: ' num2str(artoaWorkspace.float.floatname) ...
    ' Cycle: ' num2str(artoaWorkspace.float.cycle(1)) ...
    ' - Time of arrival' ...
];
titleHandle = title(artoaGui.figures.editTimeOfArrival.CurrentAxes, titleVal, 'FontSize', 10);
set(titleHandle, 'Color', 'blue');

% set x and y label
xlabel(artoaGui.figures.editTimeOfArrival.CurrentAxes, 'Message Date', 'FontSize', 10);
ylabel(artoaGui.figures.editTimeOfArrival.CurrentAxes, 'Time of arrival', 'FontSize', 10);

hold off;



end

