function [] = temperature()
%TEMPERATURE Defines the ARTOA4 edit temperature window.

global artoaGui artoaWorkspace;

%% Initialize required variables

windowTitle = [ 'ARTOA4 - Float ' num2str(artoaWorkspace.float.floatname) ' - Temperature' ];


%% Initialize temperature gui

artoaGui.figures.editTemperature = figure( ...
    'Name', windowTitle, ...
    'NumberTitle', 'off' ...
);
addToolbarExplorationButtons(artoaGui.figures.editTemperature);

artoaGui.editTemperature = struct();

set( ...
    artoaGui.figures.editTemperature, ...
    'CloseRequestFcn', ...
    'artoa.controller.edit.temperature.close();' ...
);

%% Generate Plot

artoa.controller.edit.updateAvailablePlots();

set(gca, 'Position', [0.13 0.11 0.706 0.815]);

%% Generate Controls

left = .85;
width = .14;
buttonHeight = .05;

artoaGui.editTemperature.frameControls = uipanel( ...
    'Title', 'Data', ...
    'Units', 'normalized', ...
    'BackgroundColor', 'white', ...
    'Position', [left .11 width .815] ...
);

artoaGui.editTemperature.buttonPick = uicontrol( ...
    'Parent', artoaGui.editTemperature.frameControls, ...
    'String', 'Pick', ...
    'Style', 'PushButton', ...
    'FontSize', 8, ...
    'Units', 'normalized', ...
    'Position', [.156 .9 .69 buttonHeight], ...
    'CallBack', 'artoa.controller.edit.temperature.pickPolygon();' ...
);

artoaGui.editTemperature.buttonApply = uicontrol( ...
    'Parent', artoaGui.editTemperature.frameControls, ...
    'String', 'Apply', ...
    'Style', 'PushButton', ...
    'FontSize', 8, ...
    'Units', 'normalized', ...
    'Position', [.156 .85 .69 buttonHeight], ...
    'CallBack', 'artoa.controller.edit.temperature.applyStatusToSelectedPoints(1);' ...
);

artoaGui.editTemperature.buttonReset = uicontrol( ...
    'Parent', artoaGui.editTemperature.frameControls, ...
    'String', 'Reset', ...
    'Style', 'PushButton', ...
    'FontSize', 8, ...
    'Units', 'normalized', ...
    'Position', [.156 .8 .69 buttonHeight], ...
    'CallBack', 'artoa.controller.edit.temperature.applyStatusToSelectedPoints(0);' ...
);

artoaGui.editTemperature.buttonDelete = uicontrol( ...
    'Parent', artoaGui.editTemperature.frameControls, ...
    'String', 'Delete', ...
    'Style', 'PushButton', ...
    'FontSize', 8, ...
    'Units', 'normalized', ...
    'Position', [.156 .7 .69 buttonHeight], ...
    'CallBack', 'artoa.controller.edit.temperature.applyStatusToSelectedPoints(2);' ...
);

artoaGui.editTemperature.buttonApplyAll = uicontrol( ...
    'Parent', artoaGui.editTemperature.frameControls, ...
    'String', 'Apply all', ...
    'Style', 'PushButton', ...
    'FontSize', 8, ...
    'Units', 'normalized', ...
    'Position', [.156 .5 .69 buttonHeight], ...
    'CallBack', 'artoa.controller.edit.temperature.applyStatusToAllPointsExceptDeleted(1);' ...
);

artoaGui.editTemperature.buttonResetAll = uicontrol( ...
    'Parent', artoaGui.editTemperature.frameControls, ...
    'String', 'Reset all', ...
    'Style', 'PushButton', ...
    'FontSize', 8, ...
    'Units', 'normalized', ...
    'Position', [.156 .45 .69 buttonHeight], ...
    'CallBack', 'artoa.controller.edit.temperature.applyStatusToAllPointsExceptDeleted(0);' ...
);

artoaGui.editTemperature.buttonReplot = uicontrol( ...
    'Parent', artoaGui.editTemperature.frameControls, ...
    'String', 'Replot', ...
    'Style', 'PushButton', ...
    'FontSize', 8, ...
    'Units', 'normalized', ...
    'Position', [.156 .05 .69 buttonHeight], ...
    'CallBack', 'artoa.controller.edit.temperature.plot();' ...
);

end

